package com.redhat.thermostat.tools.eclipse.plugin.wizards;

import java.util.HashMap;

import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.ModifyEvent;
import org.eclipse.swt.events.ModifyListener;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Text;

public class ThermostatProjectCreationWizardPage extends WizardPage {
    private Text projectText;

    private boolean agentSelected = false;
    private boolean clientSelected = false;
    private boolean commonSelected = false;
    private boolean distributionSelected = false;

    public ThermostatProjectCreationWizardPage() {
        super("wizardPage");
        setTitle("Thermostat Wizard");
        setDescription("This wizard creates a new Thermostat Plugin.");
    }

    public void createControl(Composite parent) {
        Composite container = new Composite(parent, SWT.NULL);
        GridLayout layout = new GridLayout();
        container.setLayout(layout);
        
        GridData gd = new GridData(GridData.FILL_HORIZONTAL);
        Label projectNameLabel = new Label(container, SWT.NULL);
        projectNameLabel.setText("&Project name:");
        
        projectText = new Text(container, SWT.BORDER | SWT.SINGLE);
        gd = new GridData(GridData.FILL_HORIZONTAL);
        projectText.setLayoutData(gd);
        projectText.addModifyListener(new ModifyListener() {
            public void modifyText(ModifyEvent e) {
                dialogChanged();
            }
        });
        
        Label componentLabel = new Label(container, SWT.NULL);
        componentLabel.setText("&Select components you would like to include in the project: ");
        
        Button agentButton = new Button(container, SWT.CHECK);
        agentButton.setText("Agent");
        agentButton.addSelectionListener(new SelectionAdapter() {
            @Override
            public void widgetSelected(SelectionEvent e){
                Button button = (Button) e.widget;
                if (button.getSelection()) {
                    agentSelected = true;
                } else {
                    agentSelected = false;
                }
            }
        });
        
        Button clientButton = new Button(container, SWT.CHECK);
        clientButton.setText("Client");
        clientButton.addSelectionListener(new SelectionAdapter() {
            @Override
            public void widgetSelected(SelectionEvent e){
                Button button = (Button) e.widget;
                if (button.getSelection()) {
                    clientSelected = true;
                } else {
                    clientSelected = false;
                }
            }
        });
        
        Button commonButton = new Button(container, SWT.CHECK);
        commonButton.setText("Common");
        commonButton.addSelectionListener(new SelectionAdapter() {
            @Override
            public void widgetSelected(SelectionEvent e){
                Button button = (Button) e.widget;
                if (button.getSelection()) {
                    commonSelected = true;
                } else {
                    commonSelected = false;
                }
            }
        });
        
        Button distributionButton = new Button(container, SWT.CHECK);
        distributionButton.setText("Distribution");
        distributionButton.addSelectionListener(new SelectionAdapter() {
            @Override
            public void widgetSelected(SelectionEvent e){
                Button button = (Button) e.widget;
                if (button.getSelection()) {
                    distributionSelected = true;
                } else {
                    distributionSelected = false;
                }
            }
        });
        
        initialize();
        dialogChanged();

        setControl(container);
    }

    private void initialize() {
        projectText.setText("Thermostat-Plugin-Project");
    }

    private void dialogChanged() {
        String projectName = getProjectName();
        if (projectName.length() == 0) {
            updateStatus("Project name must be specified");
            return;
        }
        if (projectName.replace('\\', '/').indexOf('/', 1) > 0) {
            updateStatus("Project name must be valid");
            return;
        }
        if (projectName.contains(" ")) {
            updateStatus("Project name must be valid");
            return;
        }
        updateStatus(null);
    }

    private void updateStatus(String message) {
        setErrorMessage(message);
        setPageComplete(message == null);
    }

    public String getProjectName() {
        return projectText.getText();
    }

    public HashMap<String, Boolean> getSelectedComponents() {
        HashMap<String, Boolean> selectedComponentBoxes = new HashMap<String, Boolean>();
        
        selectedComponentBoxes.put("agent", agentSelected);
        selectedComponentBoxes.put("client", clientSelected);
        selectedComponentBoxes.put("common", commonSelected);
        selectedComponentBoxes.put("distribution", distributionSelected);
        
        return selectedComponentBoxes;
    }
}
